@@ -29,16 +29,20 @@ def test_call(points, tref):
 
 
 @pytest.mark.parametrize(
-    "points, pref",
+    "points, pref, honor_grid",
     (
-        ([0.5, 0.5], 1.0),
-        ([1.5, 1.5], 4.75735931),
-        ([[0.5, 0.5], [1.5, 1.5]], [1.0, 4.75735931]),
+        ([0.5, 0.5], 1.0, False),
+        ([0.5, 0.5], 1.0, True),
+        ([1.5, 1.5], 4.75735931, False),
+        ([1.5, 1.5], 5.0, True),
+        ([[0.5, 0.5], [1.5, 1.5]], [1.0, 4.75735931], False),
+        ([[0.5, 0.5], [1.5, 1.5]], [1.0, 5.0], True),
     ),
 )
-def test_raytrace(points, pref):
+def test_raytrace(points, pref, honor_grid):
     sources = 0.0, 0.0
     tt = eik2d.solve(sources, nsweep=2, return_gradient=True)
-    rays = tt.raytrace(points, stepsize=1.0)
+    rays = tt.raytrace(points, stepsize=1.0, honor_grid=honor_grid)
+    print(rays)
 
     allclose(pref, rays, lambda x: x.sum())
